@@ -15,7 +15,6 @@ from prompt_toolkit.buffer import Buffer
 from prompt_toolkit.filters import Always
 from prompt_toolkit.interface import CommandLineInterface, Application
 from prompt_toolkit.interface import AbortAction, AcceptAction
-from prompt_toolkit.utils import Callback
 from prompt_toolkit.auto_suggest import AutoSuggestFromHistory
 from prompt_toolkit.history import InMemoryHistory, FileHistory
 
@@ -65,13 +64,14 @@ class ChangeDirHandler(object):
 
 
 class EditHandler(object):
-    def __init__(self, popen_cls=None, env=None):
+    def __init__(self, popen_cls=None, env=None, err=sys.stderr):
         if popen_cls is None:
             popen_cls = subprocess.Popen
         self._popen_cls = popen_cls
         if env is None:
             env = os.environ
         self._env = env
+        self._err = err
 
     def _get_editor_command(self):
         if 'EDITOR' in self._env:
@@ -97,8 +97,14 @@ class EditHandler(object):
             f.write(all_commands)
             f.flush()
             editor = self._get_editor_command()
-            p = self._popen_cls([editor, f.name])
-            p.communicate()
+            try:
+                p = self._popen_cls([editor, f.name])
+                p.communicate()
+            except OSError:
+                self._err.write("Unable to launch editor: %s\n"
+                                "You can configure which editor to use by "
+                                "exporting the EDITOR environment variable.\n"
+                                % editor)
 
 
 class ProfileHandler(object):
@@ -272,7 +278,7 @@ class AWSShell(object):
     def run(self):
         while True:
             try:
-                document = self.cli.run()
+                document = self.cli.run(reset_current_buffer=True)
                 text = document.text
             except InputInterrupt:
                 pass
@@ -416,7 +422,7 @@ class AWSShell(object):
             buffer=self.create_buffer(completer, history),
             on_abort=AbortAction.RETRY,
             on_exit=AbortAction.RAISE_EXCEPTION,
-            on_input_timeout=Callback(self.on_input_timeout),
+            on_input_timeout=self.on_input_timeout,
             key_bindings_registry=self.key_manager.manager.registry,
         )
 
